==> netease_roomkit_interface-0.0.1-rc.2.tar.gz: lib/src/platform_interface/room_rtc_controller_platform.dart <==
// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'package:plugin_platform_interface/plugin_platform_interface.dart';
import 'package:netease_common/netease_common.dart';
import 'package:netease_roomkit_interface/netease_roomkit_interface.dart';
import 'package:netease_roomkit_interface/src/method_channel/method_channel_room_rtc_controller.dart';

abstract class RoomRtcControllerPlatform extends PlatformInterface {
  static final Object _token = Object();

  RoomRtcControllerPlatform() : super(token: _token);

  static RoomRtcControllerPlatform _instance = MethodChannelRoomRtcController();

  static RoomRtcControllerPlatform get instance => _instance;

  static set instance(RoomRtcControllerPlatform instance) {
    PlatformInterface.verify(instance, _token);
    _instance = instance;
  }

  Future<VoidResult> joinRtcChannel(String roomUuid);

  Future<VoidResult> leaveRtcChannel(String roomUuid);

  Future<VoidResult> muteMyAudio(String roomUuid);

  Future<VoidResult> unmuteMyAudio(String roomUuid);

  Future<VoidResult> muteMyVideo(String roomUuid);

  Future<VoidResult> unmuteMyVideo(String roomUuid);

  Future<VoidResult> muteMemberAudio(String roomUuid, String uuid);

  Future<VoidResult> unmuteMemberAudio(String roomUuid, String uuid);

  Future<VoidResult> muteMemberVideo(String roomUuid, String uuid);

  Future<VoidResult> unmuteMemberVideo(String roomUuid, String uuid);

  Future<VoidResult> startScreenShare(String roomUuid, {String? iosAppGroup});

  Future<VoidResult> stopScreenShare(String roomUuid);

  Future<VoidResult> stopMemberScreenShare(String roomUuid, String uuid);

  Future<VoidResult> subscribeRemoteVideoStream(String roomUuid,
      String userUuid, NEVideoStreamType streamType, bool subscribe);

  Future<VoidResult> adjustUserPlaybackSignalVolume(
      String roomUuid, String userUuid, int volume);

  Future<VoidResult> subscribeRemoteSubStreamVideo(
      String roomUuid, String userUuid, bool subscribe);

  Future<VoidResult> setSpeakerphoneOn(String roomUuid, bool on);

  Future<bool> isSpeakerphoneOn(String roomUuid);

  Future<VoidResult> stopAudioDump(String roomUuid);

  Future<VoidResult> startAudioDump(String roomUuid, NEAudioDumpType type);

  Future<VoidResult> enableAudioVolumeIndication(
      String roomUuid, bool enable, int interval);

  Future<VoidResult> startRtcChannelMediaRelay(String roomUuid);

  Future<VoidResult> stopRtcChannelMediaRelay(String roomUuid);

  Future<VoidResult> startAudioMixing(
      String roomUuid, NECreateAudioMixingOption option);

  Future<VoidResult> playEffect(
      String roomUuid, int id, NECreateAudioEffectOption option);

  Future<VoidResult> stopAudioMixing(String roomUuid);

  Future<VoidResult> stopEffect(String roomUuid, int id);

  Future<VoidResult> setAudioMixingSendVolume(String roomUuid, int volume);

  Future<VoidResult> setAudioMixingPlaybackVolume(String roomUuid, int volume);

  Future<VoidResult> setEffectSendVolume(String roomUuid, int id, int volume);

  Future<VoidResult> setEffectPlaybackVolume(
      String roomUuid, int id, int volume);

  Future<VoidResult> stopAllEffects(String roomUuid);

  Future<VoidResult> enableEarBack(String roomUuid, bool enable, int volume);

  Future<VoidResult> switchCamera(String roomUuid);

  Future<VoidResult> addBeautyFilter(String roomUuid, String path);

  Future<VoidResult> addBeautySticker(String roomUuid, String path);

  Future<VoidResult> enableBeauty(String roomUuid, bool isOpenBeauty);

  Future<VoidResult> removeBeautyFilter(
    String roomUuid,
  );

  Future<VoidResult> removeBeautySticker(
    String roomUuid,
  );

  Future<VoidResult> startBeauty(
    String roomUuid,
  );

  Future<VoidResult> stopBeauty(
    String roomUuid,
  );

  Future<VoidResult> setBeautyFilterLevel(String roomUuid, double level);

  Future<VoidResult> setBeautyEffect(
      String roomUuid, NERoomBeautyEffectType beautyType, double level);

  Future<VoidResult> enableVirtualBackground(String roomUuid, bool enabled,
      NERoomVirtualBackgroundSource backgroundSource);
}

==> netease_roomkit_interface-1.26.0.tar.gz: lib/src/platform_interface/room_rtc_controller_platform.dart <==
// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'package:plugin_platform_interface/plugin_platform_interface.dart';
import 'package:netease_common/netease_common.dart';
import 'package:netease_roomkit_interface/netease_roomkit_interface.dart';
import 'package:netease_roomkit_interface/src/method_channel/method_channel_room_rtc_controller.dart';

abstract class RoomRtcControllerPlatform extends PlatformInterface {
  static final Object _token = Object();

  RoomRtcControllerPlatform() : super(token: _token);

  static RoomRtcControllerPlatform _instance = MethodChannelRoomRtcController();

  static RoomRtcControllerPlatform get instance => _instance;

  static set instance(RoomRtcControllerPlatform instance) {
    PlatformInterface.verify(instance, _token);
    _instance = instance;
  }

  Future<VoidResult> startPreview(String roomUuid);

  Future<VoidResult> stopPreview(String roomUuid, bool releaseRtc);

  Future<VoidResult> joinRtcChannel(String roomUuid);

  Future<VoidResult> leaveRtcChannel(String roomUuid);

  Future<VoidResult> muteMyAudio(String roomUuid, bool enableMediaPub);

  Future<VoidResult> unmuteMyAudio(String roomUuid, bool enableMediaPub);

  Future<VoidResult> enableMediaPub(
      String roomUuid, int mediaType, bool enable);

  Future<VoidResult> pauseLocalAudioRecording(String roomUuid);

  Future<VoidResult> resumeLocalAudioRecording(String roomUuid);

  Future<VoidResult> muteMyVideo(String roomUuid);

  Future<VoidResult> unmuteMyVideo(String roomUuid);

  Future<VoidResult> pauseLocalVideoCapture(String roomUuid);

  Future<VoidResult> resumeLocalVideoCapture(String roomUuid);

  Future<VoidResult> muteMemberAudio(String roomUuid, String uuid);

  Future<VoidResult> unmuteMemberAudio(String roomUuid, String uuid);

  Future<VoidResult> muteMemberVideo(String roomUuid, String uuid);

  Future<VoidResult> unmuteMemberVideo(String roomUuid, String uuid);

  Future<VoidResult> startScreenShare(String roomUuid, {String? iosAppGroup});

  Future<VoidResult> stopScreenShare(String roomUuid);

  Future<VoidResult> stopMemberScreenShare(String roomUuid, String uuid);

  Future<VoidResult> subscribeRemoteVideoStream(String roomUuid,
      String userUuid, NEVideoStreamType streamType, bool subscribe);

  Future<VoidResult> subscribeRemoteAudioStream(
      String roomUuid, String userUuid, bool subscribe);

  Future<VoidResult> adjustUserPlaybackSignalVolume(
      String roomUuid, String userUuid, int volume);

  Future<VoidResult> adjustPlaybackSignalVolume(String roomUuid, int volume);

  Future<VoidResult> subscribeRemoteSubStreamVideo(
      String roomUuid, String userUuid, bool subscribe);

  Future<VoidResult> setSpeakerphoneOn(String roomUuid, bool on);

  Future<bool> isSpeakerphoneOn(String roomUuid);

  Future<VoidResult> stopAudioDump(String roomUuid);

  Future<VoidResult> startAudioDump(String roomUuid, NEAudioDumpType type);

  Future<VoidResult> enableAudioVolumeIndication(
      String roomUuid, bool enable, int interval,
      [bool vad = false]);

  Future<VoidResult> startRtcChannelMediaRelay(String roomUuid);

  Future<VoidResult> stopRtcChannelMediaRelay(String roomUuid);

  Future<VoidResult> startAudioMixing(
      String roomUuid, NECreateAudioMixingOption option);

  Future<VoidResult> playEffect(
      String roomUuid, int id, NECreateAudioEffectOption option);

  Future<VoidResult> stopAudioMixing(String roomUuid);

  Future<VoidResult> stopEffect(String roomUuid, int id);

  Future<VoidResult> setAudioMixingSendVolume(String roomUuid, int volume);

  Future<VoidResult> setAudioMixingPlaybackVolume(String roomUuid, int volume);

  Future<VoidResult> setEffectSendVolume(String roomUuid, int id, int volume);

  Future<VoidResult> setEffectPlaybackVolume(
      String roomUuid, int id, int volume);

  Future<VoidResult> stopAllEffects(String roomUuid);

  Future<VoidResult> enableEarBack(String roomUuid, bool enable, int volume);

  Future<VoidResult> switchCamera(String roomUuid);

  Future<VoidResult> addBeautyFilter(String roomUuid, String path);

  Future<VoidResult> addBeautySticker(String roomUuid, String path);

  Future<VoidResult> enableBeauty(String roomUuid, bool isOpenBeauty);

  Future<VoidResult> removeBeautyFilter(
    String roomUuid,
  );

  Future<VoidResult> removeBeautySticker(
    String roomUuid,
  );

  Future<VoidResult> startBeauty(
    String roomUuid,
  );

  Future<VoidResult> stopBeauty(
    String roomUuid,
  );

  Future<VoidResult> setBeautyFilterLevel(String roomUuid, double level);

  Future<VoidResult> setBeautyEffect(
      String roomUuid, NERoomBeautyEffectType beautyType, double level);

  Future<VoidResult> enableVirtualBackground(String roomUuid, bool enabled,
      NERoomVirtualBackgroundSource backgroundSource);

  Future<VoidResult> pauseAudioMixing(String roomUuid);

  Future<VoidResult> adjustRecordingSignalVolume(String roomUuid, int volume);

  Future<VoidResult> resumeAudioMixing(String roomUuid);

  Future<VoidResult> setRecordDeviceMute(String roomUuid, bool mute);

  Future<VoidResult> setClientRole(String roomUuid, int role);

  Future<VoidResult> setLocalAudioProfile(
      String roomUuid, int profile, int scenario);

  Future<VoidResult> setChannelProfile(String roomUuid, int value);

  Future<VoidResult> enableAudioAINS(String roomUuid, bool enable);

  Future<VoidResult> enableLoopbackRecording(String roomUuid, bool enable);

  Future<NEResult<int>> enableEncryption(
      String roomUuid, String encryptionKey, NEEncryptionMode encryptionMode);

  Future<NEResult<int>> disableEncryption(String roomUuid);

  Future<VoidResult> setParameters(String roomUuid, Map<String, Object> params);

  Future<VoidResult> disconnectMyAudio(String roomUuid);

  Future<VoidResult> reconnectMyAudio(String roomUuid);
}
